@@ -1,7 +1,8 @@
-/*
+/* 
 This file is part of rt-app - https://launchpad.net/rt-app
 Copyright (C) 2010  Giacomo Bagnoli <g.bagnoli@asidev.com>
 Copyright (C) 2014  Juri Lelli <juri.lelli@gmail.com>
+Copyright (C) 2014  Vincent Guittot <vincent.guittot@linaro.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -16,7 +17,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+*/ 
 
 #ifndef _RT_APP_H_
 #define _RT_APP_H_
@@ -33,10 +34,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "rt-app_types.h"
 #include "rt-app_args.h"
 
-#ifdef AQUOSA
-#include <aquosa/qres_lib.h>
-#endif /* AQUOSA */
-
 #define BUDGET_OVERP 5
 
 void *thread_body(void *arg);
