@@ -1,7 +1,8 @@
-/*
+/* 
 This file is part of rt-app - https://launchpad.net/rt-app
 Copyright (C) 2010  Giacomo Bagnoli <g.bagnoli@asidev.com>
 Copyright (C) 2014  Juri Lelli <juri.lelli@gmail.com>
+Copyright (C) 2014  Vincent Guittot <vincent.guittot@linaro.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -16,7 +17,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+*/ 
 
 #ifndef _RTAPP_ARGS_H_
 #define _RTAPP_ARGS_H_
@@ -35,10 +36,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifdef DLSCHED
 #include "dl_syscalls.h"
 #endif
-
-#ifdef JSON
 #include "rt-app_parse_config.h"
-#endif
 
 #define DEFAULT_THREAD_PRIORITY 10
 #define PATH_LENGTH 256
@@ -46,9 +44,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 void
 usage (const char* msg, int ex_code);
 
-void
-parse_thread_args(char *arg, int idx, thread_data_t *tdata, policy_t def_policy);
-
 void
 parse_command_line(int argc, char **argv, rtapp_options_t *opts);
 
