@@ -1,7 +1,8 @@
-/*
+/* 
 This file is part of rt-app - https://launchpad.net/rt-app
 Copyright (C) 2010  Giacomo Bagnoli <g.bagnoli@asidev.com>
 Copyright (C) 2014  Juri Lelli <juri.lelli@gmail.com>
+Copyright (C) 2014  Vincent Guittot <vincent.guittot@linaro.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -16,10 +17,10 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+*/ 
 
 #ifndef _RTAPP_PARSE_CONFIG_H
-#define _RTAPP_PARSE_CONFIG_H
+#define _RTAPP_PARSE_CONFIG_H 
 /* for CPU_SET macro */
 #define _GNU_SOURCE
 
@@ -36,12 +37,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifdef DLSCHED
 #include "dl_syscalls.h"
 #endif
-#include <json.h>
+#include <json-c/json.h>
 
 #define DEFAULT_THREAD_PRIORITY 10
+#define DEFAULT_THREAD_NICE	0
 #define PATH_LENGTH 256
 
 void
 parse_config(const char *filename, rtapp_options_t *opts);
+void
+parse_config_stdin(rtapp_options_t *opts);
 
 #endif // _RTAPP_PARSE_CONFIG_H
